@@ -186,15 +186,10 @@ bool handleAddLauncherAction(const QString &actionId, QObject *appletInterface,
     return false;
 }
 
-// HACK TEMP FIXME TODO IVAN
 QString storageIdFromService(KService::Ptr service)
 {
     QString storageId = service->storageId();
 
-    if (storageId.startsWith("org.kde.")) {
-        storageId = storageId.right(storageId.length() - 8);
-    }
-
     if (storageId.endsWith(".desktop")) {
         storageId = storageId.left(storageId.length() - 8);
     }
@@ -246,6 +241,13 @@ QVariantList recentDocumentActions(KService::Ptr service)
         | Activity::current()
         | Url::file();
 
+    // Due to KRecentDocument::add() bug, application name "<app>" could
+    // be stored instead of its desktop entry name "org.kde.<app>". Let's
+    // check for both in order to get all results for the application.
+    if (storageId.startsWith("org.kde.")) {
+        query = query | Agent(storageId.mid(8));
+    }
+
     ResultSet results(query);
 
     ResultSet::const_iterator resultIt;
@@ -303,6 +305,13 @@ bool handleRecentDocumentAction(KService::Ptr service, const QString &actionId,
             | Activity::current()
             | Url::file();
 
+        // Due to KRecentDocument::add() bug, application name "<app>" could
+        // be stored instead of its desktop entry name "org.kde.<app>". Let's
+        // check for both in order to get all results for the application.
+        if (storageId.startsWith("org.kde.")) {
+            query = query | Agent(storageId.mid(8));
+        }
+
         KAStats::forgetResources(query);
 
         return false;
