@@ -27,15 +27,15 @@ class RubberBand : public QQuickPaintedItem
     Q_OBJECT
 
     public:
-        RubberBand(QQuickItem *parent = 0);
+        explicit RubberBand(QQuickItem *parent = nullptr);
         ~RubberBand();
 
-        void paint(QPainter* painter) Q_DECL_OVERRIDE;
+        void paint(QPainter* painter) override;
 
-        Q_INVOKABLE bool intersects(const QRectF &rect);
+        Q_INVOKABLE bool intersects(const QRectF &rect) const;
 
     protected:
-        void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) Q_DECL_OVERRIDE;
+        void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
 
     private:
         QRectF m_geometry;
